#
# spec file for package python-pydub
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pydub
Version:        0.25.1
Release:        3.1
Summary:        Audio manipulation with Python
License:        MIT
URL:            https://github.com/jiaaro/pydub
Source:         https://github.com/jiaaro/pydub/archive/v%{version}.tar.gz#/pydub-%{version}.tar.gz
# PATCH-FIX-OPENSUSE skip_libopenh264-7.patch gh#jiaaro/pydub#700 mcepl@suse.com
# We don't have libopenh264-7 on the plain openSUSE
Patch0:         skip_libopenh264-7.patch
# PATCH-FIX-UPSTREAM gh#jiaaro/pydub#769
Patch1:         fix-assertions.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  ffmpeg
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module scipy if (%python-base without python36-base)}
Recommends:     python-scipy
Recommends:     python-simpleaudio
Requires:       ffmpeg
BuildArch:      noarch

%python_subpackages

%description
A Python module to manipulate audio with a high level interface.

%prep
%autosetup -p1 -n pydub-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export NO_OPENH264=1
%pyunittest -v test.test

%files %{python_files}
%license LICENSE
%{python_sitelib}/pydub-%{version}.dist-info
%{python_sitelib}/pydub

%changelog
* Fri Feb 16 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch fix-assertions.patch:
  * Fix assetion methods.
- Switch to pyproject macros.
* Wed Dec  7 2022 Matej Cepl <mcepl@suse.com>
- Add skip_libopenh264-7.patch which skips failing tests when
  libopenh264 is not available (which is always, because the
  library is in Packman). gh#jiaaro/pydub#700
* Wed Mar 10 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.25.1
  * Fix crashing bug in new scipy-powered EQ effects
- Release 0.25.0
  * Don't show a runtime warning about the optional ffplay
    dependency being missing until someone trys to use it
  * Documentation improvements
  * Python 3.9 support
  * Improved efficiency of loading wave files with pydub.
    AudioSegment.from_file()
  * Ensure pydub.AudioSegment().export() always retuns files with
    a seek position at the beginning of the file
  * Added more EQ effects to pydub.scipy_effects (requires scipy
    to be installed)
  * Fix a packaging bug where the LICENSE file was not included in
    the source distribution
  * Add a way to instantiate a pydub.AudioSegment() with a portion
    of an audio file via pydub.AudioSegment().from_file()
- Release 0.24.1
  * Fix bug where ffmpeg errors in Python 3 are illegible
  * Fix bug where split_on_silence fails when there are one or
    fewer nonsilent segments
  * Fix bug in fallback audioop implementation
- Release 0.24.0
  * Fix inconsistent handling of 8-bit audio
  * Fix bug where certain files will fail to parse
  * Fix bug where pyaudio stream is not closed on error
  * Allow codecs and parameters in wav and raw export
  * Fix bug in pydub.AudioSegment.from_file where supplied codec
    is ignored
  * Allow pydub.silence.split_on_silence to take a boolean for
    keep_silence
  * Fix bug where pydub.silence.split_on_silence sometimes adds
    non-silence from adjacent segments
  * Fix bug where pydub.AudioSegment.extract_wav_headers fails on
    empty wav files
  * Add new function pydub.silence.detect_leading_silence
  * Support conversion between an arbitrary number of channels and
    mono in pydub.AudioSegment.set_channels
  * Fix several issues related to reading from filelike objects
- Drop 0001-Skip-tests-that-use-unavailable-codecs.patch merged
  upstream
- Reinstate python36 build. SciPy is optional
* Sat Feb 13 2021 Dirk Müller <dmueller@suse.com>
- skip python 3.6 build (no scipy)
* Tue Feb 19 2019 Antonio Larrosa <alarrosa@suse.com>
- Enable tests. Changed source to the github release, which also
  removes the need to provide a copy of the LICENSE file.
- Add 0001-Skip-tests-that-use-unavailable-codecs.patch to skip
  tests that use codecs not supported by the official ffmpeg package
* Mon Feb 18 2019 Antonio Larrosa <alarrosa@suse.com>
- Update to 0.23.1
  * Fix bug in passing ffmpeg/avconv parameters for
    pydub.AudioSegment.from_mp3(), pydub.AudioSegment.from_flv(),
    pydub.AudioSegment.from_ogg() and pydub.AudioSegment.from_wav()
  * Fix logic bug in pydub.effects.strip_silence()
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Oct 31 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase.
* Wed Oct 31 2018 Todd R <toddrme2178@gmail.com>
- Update to 0.23.0
  * Add support for playback via simpleaudio
  * Allow users to override the type in pydub.AudioSegment().get_array_of_samples() (PR #313)
  * Fix a bug where the wrong codec was used for 8-bit audio (PR #309 - issue #308)
* Wed Jul 11 2018 alarrosa@suse.com
- Update to 0.22.1
  * Fix pydub.utils.mediainfo_json() to work with newer,
    backwards-incompatible versions of ffprobe/avprobe
- Update to 0.22.0
  * Adds support for audio with frame rates (sample rates) of 48k and higher
    (requires scipy) (PR #262, fixes #134, #237, #209)
  * Adds support for PEP 519 File Path protocol (PR #252)
  * Fixes a few places where handles to temporary files are kept open (PR #280)
  * Add the license file to the python package to aid other packaging projects
    (PR #279, fixes #274)
  * Big fix for pydub.silence.detect_silence() (PR #263)
* Thu May 10 2018 toddrme2178@gmail.com
- Update to 0.21.0
  * NOTE: Semi-counterintuitive change: using the a stride when
    slicing AudioSegment instances (for example, `sound[::5000]`)
    will return chunks of 5000ms (not 1ms chunks every 5000ms)
    (#222)
  * Debug output from ffmpeg/avlib is no longer printed to the
    console unless you set up logging (see README for how to set
    up logging for your converter) (#223)
  * All pydub exceptions are now subclasses of
    `pydub.exceptions.PydubException`
  * The utilities in `pydub.silence` now accept a
    `seek_step` argument which can optionally be passed to
    improve the performance of silence detection (#211)
  * Fix to `pydub.silence` utilities which allow you to detect
    perfect silence (#233)
  * Fix a bug where threaded code screws up your terminal session
    due to ffmpeg inheriting the stdin from the parent process.
    (#231)
  * Fix a bug where a crashing programs using pydub would leave
    behind their temporary files (#206)
- Use license tag
* Wed Oct 18 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 0.20.0
  * See changelog at https://github.com/jiaaro/pydub/blob/v0.20.0/CHANGELOG.md
* Sat Oct  1 2016 mardnh@gmx.de
- Update to version 0.16.5
  - upstream does not provide a changelog
* Mon Jul 14 2014 toddrme2178@gmail.com
- - Initial version
